# typing-speed
A python package that allows for a simple typing speed test in the terminal
## To use: 
from typing_speed import typing_speed


typing_speed.RunTest(Rounds)

Each round is 10 words devided by a space. Press enter after the last word of each round.
